/*
 * Copyright 2019 David Blanc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package fr.speekha.httpmocker.moshi

import com.squareup.moshi.JsonAdapter
import com.squareup.moshi.Moshi
import com.squareup.moshi.Types.newParameterizedType
import fr.speekha.httpmocker.model.Matcher
import fr.speekha.httpmocker.serialization.JSON_FORMAT
import fr.speekha.httpmocker.serialization.Mapper

/**
 * A mapper using Moshi to serialize/deserialize scenarios.
 */
class MoshiMapper : Mapper {

    override val supportedFormat: String = JSON_FORMAT

    private val moshi = Moshi.Builder()
        .add(HeaderAdapter())
        .add(MatcherAdapter())
        .add(ParamAdapter())
        .build()

    private val adapter: JsonAdapter<List<Matcher>> = moshi.adapter(
        newParameterizedType(List::class.java, Matcher::class.java)
    )

    override fun deserialize(payload: String): List<Matcher>? = adapter.fromJson(payload)

    override fun serialize(matchers: List<Matcher>): String = adapter.toJson(matchers)
}
